@@ -130,7 +130,7 @@
   WSGIappLocaleSet()->setLocaleString("EUCCN","R3:WSSTR Compiler flags","ͨñѡ");
   WSGIappLocaleSet()->setLocaleString("EUCCN","S3:WSSTR Compile mode","ģʽ");
   WSGIappLocaleSet()->setLocaleString("EUCCN","T3:WSSTR  Debug mode"," ģʽ");
-  WSGIappLocaleSet()->setLocaleString("EUCCN","U3:WSSTR Class library","");
+  WSGIappLocaleSet()->setLocaleString("EUCCN","U3:WSSTR Application type","Application type");
   WSGIappLocaleSet()->setLocaleString("EUCCN","V3:WSSTR  Generate class library","");
   WSGIappLocaleSet()->setLocaleString("EUCCN","W3:WSSTR Compiler","");
   WSGIappLocaleSet()->setLocaleString("EUCCN","X3:WSSTR Runtime mode,Debug mode,Runtime static mode,Debug static mode","ͨģʽ,ģʽ,̬ͨģʽ,̬ģʽ");
