@@ -130,7 +130,7 @@
   WSGIappLocaleSet()->setLocaleString("EUCJP","R3:WSSTR Compiler flags","̥ѥե饰");
   WSGIappLocaleSet()->setLocaleString("EUCJP","S3:WSSTR Compile mode","ѥˡ");
   WSGIappLocaleSet()->setLocaleString("EUCJP","T3:WSSTR  Debug mode"," ǥХå⡼");
-  WSGIappLocaleSet()->setLocaleString("EUCJP","U3:WSSTR Class library","饹饤֥");
+  WSGIappLocaleSet()->setLocaleString("EUCJP","U3:WSSTR Application type","ӥɥ");
   WSGIappLocaleSet()->setLocaleString("EUCJP","V3:WSSTR  Generate class library"," 饹饤֥ˤ");
   WSGIappLocaleSet()->setLocaleString("EUCJP","W3:WSSTR Compiler","ѥ");
   WSGIappLocaleSet()->setLocaleString("EUCJP","X3:WSSTR Runtime mode,Debug mode,Runtime static mode,Debug static mode","̾⡼,ǥХå⡼,̾凉ƥå⡼,ǥХåƥå⡼");
