@@ -130,7 +130,7 @@
   WSGIappLocaleSet()->setLocaleString("EUCKR","R3:WSSTR Compiler flags","÷");
   WSGIappLocaleSet()->setLocaleString("EUCKR","S3:WSSTR Compile mode","Ϲ");
   WSGIappLocaleSet()->setLocaleString("EUCKR","T3:WSSTR  Debug mode"," ׸");
-  WSGIappLocaleSet()->setLocaleString("EUCKR","U3:WSSTR Class library","Ŭ̺귯");
+  WSGIappLocaleSet()->setLocaleString("EUCKR","U3:WSSTR Application type","Application type");
   WSGIappLocaleSet()->setLocaleString("EUCKR","V3:WSSTR  Generate class library"," Ŭ̺귯 Ѵ.");
   WSGIappLocaleSet()->setLocaleString("EUCKR","W3:WSSTR Compiler","Ϸ");
   WSGIappLocaleSet()->setLocaleString("EUCKR","X3:WSSTR Runtime mode,Debug mode,Runtime static mode,Debug static mode"," , , ƽ , ƽ ");
