@@ -243,8 +243,10 @@ long WSCballoonHelp::_adjust(){
   WSCstring str(_bh_label->getProperty(WSNlabelString));
   WSCuchar fno;
   getPropertyV(WSNfont,&fno);
+  char* sepa = "\\n";
   long lines = str.getWords("\\n");
   if (lines == 1){
+    sepa = "\n";
     lines = str.getWords("\n");
   }
   WSCushort sw = 1;
@@ -255,7 +257,7 @@ long WSCballoonHelp::_adjust(){
     long i;
     WSCushort work;
     for(i=0; i<lines; i++){
-      WSCstring line = str.getWord(i,"\\n");
+      WSCstring line = str.getWord(i,sepa);
       work = WSGIappFontSet()->getStringWidth(  fno, &line );
       if (sw < work){
         sw = work;
