@@ -222,6 +222,10 @@ dbprintf("WSCbaseList::execInitialize %s:%d start.\n",__FILE__,__LINE__);
   if (fl != False){
     return;
   }
+  fl = WSGIappDev()->getInitializeExecuted();
+  if (fl == False){
+    return;
+  }
   long i;
   long num = _need_init->getNum();
   if (num > 0){
