@@ -46,7 +46,11 @@ WSCblink::~WSCblink(){
   }
 }
 WSCbool WSCblink::getBlinkFore(long rate){
-  return (_clock/rate) % 2;
+  long val = (_clock/rate) % 2;
+  if (val == 0){
+    return False;
+  }
+  return True;
 }
 void WSCblink::_blink_proc(WSCuchar clk,void* ptr){
   WSCblink* obj = (WSCblink*)ptr;
