@@ -31,6 +31,7 @@
 #include <WSDdev.h>
 #include <WSDappDev.h>
 #include <WSCbaseList.h>
+#include <WSDwindowDev.h>
 
 WSMFguiClassInitialize(WSCform,WSCbase);
 WSMFversion(WSCform,WSCbase);
@@ -900,3 +901,14 @@ void WSCform::onGuiPolicyChange(long policy){
   redraw();
 }
 
+void WSCform::internalUpdate(){
+  WSDdev* dev = getowndev();
+  if (dev != NULL){
+    char pstyle = WS_DYNAMIC_PIXMAP;
+    dev->getValue(WSDEV_PIXMAP_STYLE,(void*)&pstyle);
+    if (pstyle == WS_DYNAMIC_PIXMAP){
+      WSDwindowDev* wdev = (WSDwindowDev*)dev->cast("WSDwindowDev");
+      wdev->destroyPixmap();
+    }
+  }
+}
