@@ -33,6 +33,7 @@
 #include <WSCcolorSet.h>
 #include <WSDappDev.h>
 #include <WSDtimer.h>
+#include <WSDwindowDev.h>
 
 WSMFguiClassInitialize(WSCwindow,WSCbase);
 WSMFversion(WSCwindow,WSCbase);
@@ -1083,3 +1084,15 @@ void WSCwindow::setVisible(WSCbool fl){
   WSCbase::setVisible(fl);
   _vis_ch_sequence = False;
 }
+void WSCwindow::internalUpdate(){
+  WSDdev* dev = getowndev();
+  if (dev != NULL){
+    char pstyle = WS_DYNAMIC_PIXMAP;
+    dev->getValue(WSDEV_PIXMAP_STYLE,(void*)&pstyle);
+    if (pstyle == WS_DYNAMIC_PIXMAP){
+      WSDwindowDev* wdev = (WSDwindowDev*)dev->cast("WSDwindowDev");
+      wdev->destroyPixmap();
+    }
+  }
+}
+
