@@ -350,7 +350,7 @@ void* WSDappDev::getExtGuiPolicyProc(char* pname){
 #endif
 }
 WSCindexData* WSDappDev::getExtGuiPolicyList(){
-  WSGIappGuiPolicy()->getExtGuiPolicyList();
+  return WSGIappGuiPolicy()->getExtGuiPolicyList();
 #if 0
   return &_ext_policy_list;
 #endif
