@@ -81,6 +81,7 @@ WSClist::WSClist(WSCbase* base,char* objname):
   _separator = WSGFstrdup(",");
   _need_ds_update = False;
   _need_scr_redraw = True;
+  _need_update_btn_area = False;
   _wy_pos_bak = 0;
   _pre_select = -1;
 
@@ -111,6 +112,7 @@ WSClist::WSClist(WSCbase* base,char* objname):
 //    WSMFpropertyDelete(WSNvirtualScroll);
     WSMFpropertyCreate(WSNseparator,  char*, _separator, WSSseparator );
     WSMFpropertyVisibleOff(WSNscrollHeight);
+    WSMFpropertyVisibleOff(WSNworkHeight);
     WSMFpropertyValueChangeDef( WSClist,WSNscrollHeight ,WSCushort);
     WSMFpropertyValueChangeDef( WSClist,WSNhbarVisible ,WSCbool);
 
@@ -984,6 +986,11 @@ void WSClist::_adjust(){
     _adjust_scr_area();
   }
 //printf("WSClist::_adjust scr_w=%d\n",_scr_area_w);
+  if (getVisible() == False){
+    _need_update_btn_area = True;
+    return;
+  }
+  _need_update_btn_area = False;
   _btn_area->setPropertyV(WSNwidth,(WSCushort)_scr_area_w);
   _btn_area->setPropertyV(WSNheight,(WSCushort)_padding);
 
@@ -999,7 +1006,6 @@ void WSClist::_adjust(){
   long cnt = 0;
   long i;
   WSCstring title(_title_string);
-//printf("WSClist::_adjust btnnum=%d\n",btnnum);
   for(i=0; i<num; i++){
     WSCbase* item = (WSCbase*)children[i];
     if (item->cast("WSCgripHand") != NULL){
@@ -1176,6 +1182,9 @@ void WSClist::update(){
     _need_ds_update = False;
     _set_ds_instance();
   }
+  if (_need_update_btn_area != False){
+    _adjust();
+  }
   if ( _need_update != 0){
     updateList();
     if (_pixmap_style == WS_DYNAMIC_PIXMAP){
