@@ -619,14 +619,17 @@ WSCstring WSCdirTree::getDirInf(){
     long vis = (long)item->getProperty(WSNvis);
     long level = (long)item->getUserData(WS_LIST_INDENT_LEVEL);
     long selected = (long)item->getUserData(SELECT_STATUS);
-    WSCvariant path = item->getProperty(WSNuserString);
-    WSCvariant fname = item->getProperty(WSNlabelString);
-    WSCvariant iname = item->getProperty(WSNlabelPixmap);
+    WSCstring path = item->getProperty(WSNuserString);
+    WSCstring fname = item->getProperty(WSNlabelString);
+    WSCstring iname = item->getProperty(WSNlabelPixmap);
     long val = (long)_dir_inf[(char*)path];
     if (i!=0){
       ret << "\n";
     }
     WSCstring tmp;
+    path.replaceString(",","\\,",0);
+    fname.replaceString(",","\\,",0);
+    iname.replaceString(",","\\,",0);
     tmp << path << "," << fname << "," << iname << ","
         << val << "," << level << "," << selected << "," << vis;
     ret << tmp;
@@ -640,9 +643,16 @@ void WSCdirTree::setDirInf(WSCstring inf){
   long select_pos = 0;
   for(i=0; i<num; i++){
     WSCstring line = inf.getWord(i,"\n");
+    char tmps[2];
+    tmps[0] = 0xff;
+    tmps[1] = 0;
+    line.replaceString("\\,",tmps,0);
     WSCstring path = line.getWord(0,",");
+    path.replaceString(tmps,",",0);
     WSCstring fname = line.getWord(1,",");
+    fname.replaceString(tmps,",",0);
     WSCstring iname = line.getWord(2,",");
+    iname.replaceString(tmps,",",0);
     long val = atoi(line.getWord(3,","));
     long level = atoi(line.getWord(4,","));
     long selected = atoi(line.getWord(5,","));
