@@ -33,6 +33,7 @@
 #include <WSDmouse.h>
 #include <WSDwindowDev.h>
 #include <WSCfontSet.h>
+#include <WSCwindow.h>
 
 WSMFguiClassInitialize(WSCfform,WSCbase);
 WSMFversion(WSCfform,WSCbase);
@@ -77,6 +78,7 @@ WSCfform::WSCfform(WSCbase* base,char* objname):WSCbase(base,objname){
   _mouse_pressed_resize = False;
   _floated = False;
   _indicator = True;
+  _start_moving = False;
 //  _dev_form = NULL;
 //  _dev_win = NULL;
   _title_string = WSGFstrdup("");
@@ -980,6 +982,7 @@ void WSCfform::onMousePress(WSCpoint* pt){
       _mouse_x = pt->x;
       _mouse_y = pt->y;
       _mouse_pressed = True;
+      _start_moving = False;
     }
   }else{
     if (pt->x > 0 && pt->x < _w  - _margin &&
@@ -987,6 +990,7 @@ void WSCfform::onMousePress(WSCpoint* pt){
       _mouse_x = pt->x;
       _mouse_y = pt->y;
       _mouse_pressed = True;
+      _start_moving = False;
     }
   }
   if (_floated != False){
@@ -1004,9 +1008,96 @@ void WSCfform::onMousePress(WSCpoint* pt){
         _resize_timer->startTimer();
       }
     }
+    if (_mouse_pressed_resize == False &&
+        _mouse_pressed != False ){
+      if (_move_timer == NULL){
+        _move_timer = WSDprivateTimer::getNewInstance();
+      }
+      _move_timer->stopTimer();
+      _move_timer->setWorkProc(_move_proc,this);
+      _move_timer->setRate(50);
+      _move_timer->setCont(True);
+      _move_timer->startTimer();
+    }
   }
 }
 
+WSCwindow* _resize_frame_top = NULL;
+WSCwindow* _resize_frame_left = NULL;
+WSCwindow* _resize_frame_right = NULL;
+WSCwindow* _resize_frame_bottom = NULL;
+void _create_resize_frame_(){
+  _resize_frame_top = new WSCwindow(NULL,"sform_sep_window");
+  _resize_frame_top->initialize();
+  _resize_frame_top->setProperty(WSNtitleBar,WS_NO_MANAGE);
+  _resize_frame_top->setProperty(WSNshadowThickness,0);
+  _resize_frame_top->setProperty(WSNbackColor,"#606060");
+  _resize_frame_top->setProperty(WSNindicatorOn,False);
+
+  _resize_frame_left = new WSCwindow(NULL,"sform_sep_window");
+  _resize_frame_left->initialize();
+  _resize_frame_left->setProperty(WSNtitleBar,WS_NO_MANAGE);
+  _resize_frame_left->setProperty(WSNshadowThickness,0);
+  _resize_frame_left->setProperty(WSNbackColor,"#606060");
+  _resize_frame_left->setProperty(WSNindicatorOn,False);
+
+  _resize_frame_right = new WSCwindow(NULL,"sform_sep_window");
+  _resize_frame_right->initialize();
+  _resize_frame_right->setProperty(WSNtitleBar,WS_NO_MANAGE);
+  _resize_frame_right->setProperty(WSNshadowThickness,0);
+  _resize_frame_right->setProperty(WSNbackColor,"#606060");
+  _resize_frame_right->setProperty(WSNindicatorOn,False);
+
+  _resize_frame_bottom = new WSCwindow(NULL,"sform_sep_window");
+  _resize_frame_bottom->initialize();
+  _resize_frame_bottom->setProperty(WSNtitleBar,WS_NO_MANAGE);
+  _resize_frame_bottom->setProperty(WSNshadowThickness,0);
+  _resize_frame_bottom->setProperty(WSNbackColor,"#606060");
+  _resize_frame_bottom->setProperty(WSNindicatorOn,False);
+}
+void _move_resize_frame_(long x,long y,WSCulong w,WSCulong h){
+  _resize_frame_top->setVisible(True);
+  _resize_frame_bottom->setVisible(True);
+  _resize_frame_left->setVisible(True);
+  _resize_frame_right->setVisible(True);
+
+  _resize_frame_top->setProperty(WSNx,x);
+  _resize_frame_top->setProperty(WSNy,y);
+  _resize_frame_top->setProperty(WSNwidth,w);
+  _resize_frame_top->setProperty(WSNheight,5);
+
+  _resize_frame_left->setProperty(WSNx,x);
+  _resize_frame_left->setProperty(WSNy,y);
+  _resize_frame_left->setProperty(WSNwidth,5);
+  _resize_frame_left->setProperty(WSNheight,h);
+
+  _resize_frame_right->setProperty(WSNx,x+w-5);
+  _resize_frame_right->setProperty(WSNy,y);
+  _resize_frame_right->setProperty(WSNwidth,5);
+  _resize_frame_right->setProperty(WSNheight,h);
+
+  _resize_frame_bottom->setProperty(WSNx,x);
+  _resize_frame_bottom->setProperty(WSNy,y +h -5);
+  _resize_frame_bottom->setProperty(WSNwidth,w);
+  _resize_frame_bottom->setProperty(WSNheight,5);
+
+  _resize_frame_top->setMapStatus(WS_TOP);
+  _resize_frame_left->setMapStatus(WS_TOP);
+  _resize_frame_right->setMapStatus(WS_TOP);
+  _resize_frame_top->setMapStatus(WS_TOP);
+
+  _resize_frame_left->update();
+  _resize_frame_right->update();
+  _resize_frame_bottom->update();
+  _resize_frame_top->update();
+}
+void _popdown_resize_frame_(){
+  _resize_frame_top->setVisible(False);
+  _resize_frame_bottom->setVisible(False);
+  _resize_frame_left->setVisible(False);
+  _resize_frame_right->setVisible(False);
+}
+
 void WSCfform::_resize_proc(void* ptr){
   WSCfform* _this = (WSCfform*)ptr;
 
@@ -1014,14 +1105,34 @@ void WSCfform::_resize_proc(void* ptr){
   WSGIappMouse()->getMousePosition(&x,&y,_this);
   WSCulong status = WSGIappMouse()->getMouseStatus();
 
+  if (status & ( WS_MOUSE_BTN1 | WS_MOUSE_BTN2 | WS_MOUSE_BTN3)){
+  }else{
+    _this->_mouse_pressed = False;
+    _this->_mouse_pressed_resize = False;
+  }
   if (_this->_mouse_pressed_resize != False){
+    if (_resize_frame_top == NULL){
+      _create_resize_frame_();
+    }
+    if (_resize_frame_top == NULL){
+      return;
+    }
+    if (x < 20){
+      x = 20;
+    }
+    if (y < 20){
+      y = 20;
+    }
+    _move_resize_frame_(_this->_x,_this->_y,x+5,y+5);
+
+#if 0
     if (x > 20){
       _this->setProperty(WSNwidth,x + 5);
     }
     if (y > 20){
       _this->setProperty(WSNheight,y + 5);
     }
-    _this->update();
+#endif
 
     if (status & ( WS_MOUSE_BTN1 | WS_MOUSE_BTN2 | WS_MOUSE_BTN3)){
     }else{
@@ -1030,8 +1141,19 @@ void WSCfform::_resize_proc(void* ptr){
     }
 
   }else{
+    if (_resize_frame_top != NULL){
+      _popdown_resize_frame_();
+    }
     _resize_timer->stopTimer();
     _this->_mouse_pressed_resize = False;
+    if (x < 20){
+      x = 20;
+    }
+    if (y < 20){
+      y = 20;
+    }
+    _this->setProperty(WSNwidth,x + 5);
+    _this->setProperty(WSNheight,y + 5);
   }
 
 }
@@ -1046,14 +1168,16 @@ void WSCfform::onMouseMove(WSCpoint* pt){
     if (_mouse_pressed == False){
       return;
     }
+    WSCbool start_move = False;
     if (_mouse_x - pt->x > 100){
 //printf("diff!!! %s\n",getInstanceName());
       _x_bak = _x;
       _y_bak = _y;
       _x = pt->x;
       _y = pt->y;
-      setFloated(True);
-      _mouse_pressed = False;
+      if (_start_moving == False){
+        start_move = True;
+      }
     }
     if (_mouse_x - pt->x < -100){
 //printf("diff!!! %s\n",getInstanceName());
@@ -1061,8 +1185,9 @@ void WSCfform::onMouseMove(WSCpoint* pt){
       _y_bak = _y;
       _x = pt->x;
       _y = pt->y;
-      setFloated(True);
-      _mouse_pressed = False;
+      if (_start_moving == False){
+        start_move = True;
+      }
     }
     if (_mouse_y - pt->y > 100){
 //printf("diff!!! %s\n",getInstanceName());
@@ -1070,8 +1195,9 @@ void WSCfform::onMouseMove(WSCpoint* pt){
       _y_bak = _y;
       _x = pt->x;
       _y = pt->y;
-      setFloated(True);
-      _mouse_pressed = False;
+      if (_start_moving == False){
+        start_move = True;
+      }
     }
     if (_mouse_y - pt->y < -100){
 //printf("diff!!! %s\n",getInstanceName());
@@ -1079,58 +1205,76 @@ void WSCfform::onMouseMove(WSCpoint* pt){
       _y_bak = _y;
       _x = pt->x;
       _y = pt->y;
-      setFloated(True);
-      _mouse_pressed = False;
+      if (_start_moving == False){
+        start_move = True;
+      }
     }
-  }else{
-    if (_mouse_pressed_resize != False){
-#if 0
-      if (pt->x > 20){
-        setProperty(WSNwidth,pt->x + 5);
-      }
-      if (pt->y > 20){
-        setProperty(WSNheight,pt->y + 5);
-      }
-      needUpdate();
-#endif
-    }else
-    if ((_mouse_x > 0 && _mouse_x < 15 &&
-         _mouse_y > 0 && _mouse_y < _h &&
-         _orientation == WS_VERTICAL) ||
-        (_mouse_x > 0 && _mouse_x < _w &&
-         _mouse_y > 0 && _mouse_y < 15 &&
-         _orientation != WS_VERTICAL) ){
-      short x,y;
-      WSGIappMouse()->getMousePosition(&x,&y);
-      x -= _mouse_x;
-      y -= _mouse_y;
-      setProperty(WSNx,x-5);
-      setProperty(WSNy,y-5);
-      needUpdate();
-      if (getParent() != NULL){
-        WSGIappMouse()->getMousePosition(&x,&y,getParent());
-        x -= _mouse_x;
-        y -= _mouse_y;
-        if ( x - _x_original < 100 &&
-             x - _x_original > -100 &&
-             y - _y_original < 100 &&
-             y - _y_original > -100 ){
-          setFloated(False);
-          _mouse_pressed = False;
-          _change_sequence = False;
-        }
+    if (start_move != False){
+      if (_move_timer == NULL){
+        _move_timer = WSDprivateTimer::getNewInstance();
       }
+      _move_timer->stopTimer();
+      _move_timer->setWorkProc(_move_proc,this);
+      _move_timer->setRate(50);
+      _move_timer->setCont(True);
+      _move_timer->startTimer();
+      _start_moving = True;
     }
   }
 }
 void WSCfform::onMouseRelease(WSCpoint* pt){
   WSCbase::onMouseRelease(pt);
+  if ( _mouse_pressed == True){
+    if (_floated != False){
+      short x,y;
+      WSGIappMouse()->getMousePosition(&x,&y);
+      x -= _mouse_x;
+      y -= _mouse_y;
+      if (_resize_frame_top != NULL){
+        _popdown_resize_frame_();
+      }
+      setProperty(WSNx,x-5);
+      setProperty(WSNy,y-5);
+      _update_only_xy();
+    }
+  }
   _mouse_pressed = False;
   _mouse_pressed_resize = False;
+  _start_moving = False;
 
 }
 WSDprivateTimer* WSCfform::_move_timer = NULL;
 WSDprivateTimer* WSCfform::_resize_timer = NULL;
+void WSCfform::_update_only_xy(){
+  WSDdev* dev = getowndev();
+  if (dev != NULL){
+    short ox = _x;
+    if (getXOffsetPtr() != NULL){
+      ox = _x + *(getXOffsetPtr());
+    }
+    short dx;
+    dev->getValue(WSDEV_X,&dx);
+    if (ox != dx){
+      dev->setValue(WSDEV_X,&ox);
+    }
+    short oy = _y;
+    if (getYOffsetPtr() != NULL){
+      oy = _y + *(getYOffsetPtr());
+    }
+    short dy;
+    dev->getValue(WSDEV_Y,&dy);
+    if (oy != dy){
+      dev->setValue(WSDEV_Y,&oy);
+    }
+  }
+
+  if (_update_resize != False){
+    _update_resize = False;
+    execResizeEvent();
+  }
+  WSCbase::update();
+}
+
 
 void WSCfform::_move_proc(void* ptr){
   WSCfform* _this = (WSCfform*)ptr;
@@ -1138,9 +1282,22 @@ void WSCfform::_move_proc(void* ptr){
 //fflush(stdout);
   short x,y;
   WSGIappMouse()->getMousePosition(&x,&y);
+      x -= _this->_mouse_x;
+      y -= _this->_mouse_y;
+  if (_resize_frame_top == NULL){
+    _create_resize_frame_();
+  }
+  if (_resize_frame_top == NULL){
+    return;
+  }
+
+#if 0
   _this->setProperty(WSNx,x-5);
   _this->setProperty(WSNy,y-5);
-  _this->update();
+  _this->_update_only_xy();
+#endif
+  _move_resize_frame_(x-5,y-5,_this->_w,_this->_h);
+
   WSCulong status = WSGIappMouse()->getMouseStatus();
 //printf("move_proc timer stats=0x%x  %d %d\n",status,x,y);
 //fflush(stdout);
@@ -1152,18 +1309,56 @@ void WSCfform::_move_proc(void* ptr){
   }else{
 //printf("move_proc timer stop..\n");
 //fflush(stdout);
+
     _move_timer->stopTimer();
-    _this->_change_sequence = False;
+//    _this->_change_sequence = False;
+
+    if (_resize_frame_top != NULL){
+      _popdown_resize_frame_();
+    }
+    if (_this->_floated == False){
+      WSGIappMouse()->setMousePosition(x-5,y-5);
+      _this->setFloated(True);
+//      WSCbool _vis_bk = _this->getVisible(); 
+//      if (_this->_dev != NULL){
+//        if (_vis_bk != False){
+//          _this->setVisible(False);
+//        }
+//      }
+//      _this->_set_floated();
+      _this->_mouse_pressed = False;
+      return;
+    }else{
+      _this->setProperty(WSNx,x-5);
+      _this->setProperty(WSNy,y-5);
+      _this->_update_only_xy();
+      _this->_mouse_pressed = False;
+    }
+    return;
   }
 
-  if (_this->getParent() != NULL){
-    WSGIappMouse()->getMousePosition(&x,&y,_this->getParent());
-    if ( x - _this->_x_original < 100 &&
-      x - _this->_x_original > -100 &&
-      y - _this->_y_original < 100 &&
-      y - _this->_y_original > -100 ){
+  if (_this->_floated != False){
+    if (_this->getParent() != NULL){
+      WSGIappMouse()->getMousePosition(&x,&y,_this->getParent());
+//      x -= _this->_mouse_x;
+//      y -= _this->_mouse_y;
+      if (x - _this->_x_original < 100 &&
+          x - _this->_x_original > -100 &&
+          y - _this->_y_original < 100 &&
+          y - _this->_y_original > -100 ){
 //printf("here hit!!!!!!!---------------\n");
 //fflush(stdout);
+        _move_timer->stopTimer();
+        _this->_mouse_pressed = False;
+        _this->setFloated(False);
+
+        if (_resize_frame_top != NULL){
+//printf("popdown resize frame here hit!!!!!!!---------------\n");
+          _popdown_resize_frame_();
+        }
+
+        return;
+      }
     }
   }
 }
@@ -1171,10 +1366,12 @@ void WSCfform::_move_proc(void* ptr){
 void WSCfform::_delay_proc(WSCuchar,void* ptr){
 
   WSCfform* _this = (WSCfform*)ptr;
+//  if (_this->_floated == False){
   _this->_set_floated();
-  if (_this->_floated == False){
-    return;
-  }
+  _this->_change_sequence = False;
+  return;
+//  }
+#if 0
   if (_move_timer == NULL){
     _move_timer = WSDprivateTimer::getNewInstance();
   }
@@ -1183,6 +1380,7 @@ void WSCfform::_delay_proc(WSCuchar,void* ptr){
   _move_timer->setRate(50);
   _move_timer->setCont(True);
   _move_timer->startTimer();
+#endif
 //printf("delay_proc timer started.. %s\n",_this->getInstanceName());
 }
 
@@ -1234,6 +1432,7 @@ void WSCfform::_set_floated(){
   getowndev()->setEnableEventBit(_event_mask);
 
   if (_vis_bk != False){
+//printf("_set_floated setvis->True\n");
     setVisible(True);
     setAbsoluteDraw(True);
     needUpdate();
@@ -1254,35 +1453,15 @@ void WSCfform::setFloated(WSCbool fl ){
       if (_vis_bk != False){
         setVisible(False);
       }
-//      _dev->detachClient();
     }
-#if 0
-    if (fl == False){
-      if (_dev_form == NULL){
-        if (_dev == NULL){
-          _dev_form = WSGIappDevice()->getDevObject("formDev");
-        }else{
-          _dev_form = _dev;
-        }
-      }
-      if (_dev_form != NULL){
-        setdev(_dev_form);
-      }
-    }else{
-      if (_dev_win == NULL){
-        _dev_win = WSGIappDevice()->getDevObject("windowDev");
-      }
-      if (_dev_win != NULL){
-        setdev(_dev_win);
-      }
-    }
-    if (_vis_bk != False){
-      setVisible(True);
-    }
-#endif
     _floated = fl;
   }
   WSGIappTimer()->addTriggerProc(_delay_proc,WS250MS,this);
+  if (fl == False){
+    if (_resize_frame_top != NULL){
+      _popdown_resize_frame_();
+    }
+  }
 
 //printf("delay_proc timer registered.. %s\n",getInstanceName());
 }
@@ -1326,3 +1505,15 @@ long WSCfform::getPixmapStyle(){
   return WS_DYNAMIC_PIXMAP;
 #endif
 }
+void WSCfform::internalUpdate(){
+  WSDdev* dev = getowndev();
+  if (dev != NULL){
+    char pstyle = WS_DYNAMIC_PIXMAP;
+    dev->getValue(WSDEV_PIXMAP_STYLE,(void*)&pstyle);
+    if (pstyle == WS_DYNAMIC_PIXMAP){
+      WSDwindowDev* wdev = (WSDwindowDev*)dev->cast("WSDwindowDev");
+      wdev->destroyPixmap();
+    }
+  }
+}
+
