@@ -144,9 +144,9 @@ long WSCvgraphScale::draw(){
     w -= _lw;
   }
   long i;
-  WSCushort interval = h/_num;
+  double interval = (double)h/_num;
   if (_orientation != WS_VERTICAL){
-    interval = w/_num;
+    interval = (double)w/_num;
   }
 
   WSCstring vlist(_values);
@@ -164,50 +164,50 @@ long WSCvgraphScale::draw(){
   WSDfont* fn = WSGIappFontSet()->getFont(_font);
   if (_orientation == WS_VERTICAL){
     if (_rev == False){
-      dev->drawLine(w - _lw/2,interval/2,w - _lw/2, interval/2 + interval*(_num-1)+_lw/2);
+      dev->drawLine(w - _lw/2,(short)(interval/2),w - _lw/2, (short)(interval/2 + interval*(_num-1)+_lw/2));
     }else{
-      dev->drawLine(_lw/2,interval/2,_lw/2, interval/2 + interval*(_num-1)+_lw/2);
+      dev->drawLine(_lw/2,(short)(interval/2),_lw/2, (short)(interval/2 + interval*(_num-1)+_lw/2));
     }
     for(i=0; i<num; i++){
       WSCstring tmp = blist.getWord(i,",");
       long val = atoi(tmp);
       if (val > 0){
         if (_rev == False){
-          dev->drawLine(w - _lw/2,interval/2+_lw/2 + interval*i,w - val,interval/2+ _lw/2 + interval*i);
+          dev->drawLine(w - _lw/2,(short)(interval/2+_lw/2 + interval*i),w - val,(short)(interval/2+ _lw/2 + interval*i));
         }else{
-          dev->drawLine(_lw/2,interval/2+_lw/2 + interval*i,val,interval/2+ _lw/2 + interval*i);
+          dev->drawLine(_lw/2,(short)(interval/2+_lw/2 + interval*i),val,(short)(interval/2+ _lw/2 + interval*i));
         }
       }
       WSCstring tmp2 = vlist.getWord(i,",");
 
       long fh = fn->getStringHeight(&tmp2);
       if (_rev == False){
-        dev->drawString(w - _margin,interval/2 + _lw/2 + interval*i - fh/2,100,100,
+        dev->drawString(w - _margin,(short)(interval/2 + _lw/2 + interval*i - fh/2),100,100,
                         &tmp2,_font,WS_LEFT_TOP,-1,False);
       }else{
-        dev->drawString(_margin,interval/2 + _lw/2 + interval*i - fh/2,100,100,
+        dev->drawString(_margin,(short)(interval/2 + _lw/2 + interval*i - fh/2),100,100,
                         &tmp2,_font,WS_LEFT_TOP,-1,False);
       }
     }
   }else{
     if (_rev == False){
-      dev->drawLine(interval/2,_lw/2, interval/2 + interval*(_num-1)+_lw/2,_lw/2);
+      dev->drawLine((short)(interval/2),_lw/2,(short)( interval/2 + interval*(_num-1)+_lw/2),_lw/2);
     }else{
-      dev->drawLine(interval/2,h - _lw/2,interval/2 + interval*(_num-1)+_lw/2,h -_lw/2);
+      dev->drawLine((short)(interval/2),h - _lw/2,(short)(interval/2 + interval*(_num-1)+_lw/2),h -_lw/2);
     }
     for(i=0; i<num; i++){
       WSCstring tmp = blist.getWord(i,",");
       long val = atoi(tmp);
       if (val > 0){
         if (_rev == False){
-          dev->drawLine(interval/2 + interval*i + _lw/2,
+          dev->drawLine((short)(interval/2 + interval*i + _lw/2),
                         _lw/2,
-                        interval/2 + interval*i + _lw/2,
+                        (short)(interval/2 + interval*i + _lw/2),
                         val);
         }else{
-          dev->drawLine(interval/2 + interval*i + _lw/2,
+          dev->drawLine((short)(interval/2 + interval*i + _lw/2),
                         h - _lw/2,
-                        interval/2 + interval*i + _lw/2,
+                        (short)(interval/2 + interval*i + _lw/2),
                         h - val);
         }
       }
@@ -215,10 +215,12 @@ long WSCvgraphScale::draw(){
 
       long fw = fn->getStringWidth(&tmp2);
       if (_rev == False){
-        dev->drawString( interval/2 + interval*i + _lw/2 - fw/2,_margin,100,100,
+        dev->drawString( (short)(interval/2 + interval*i + _lw/2 - fw/2),
+                        _margin,100,100,
                         &tmp2,_font,WS_LEFT_TOP,-1,False);
       }else{
-        dev->drawString( interval/2 + interval*i + _lw/2 - fw/2,h - _margin,100,100,
+        dev->drawString( (short)(interval/2 + interval*i + _lw/2 - fw/2),
+                        h - _margin,100,100,
                         &tmp2,_font,WS_LEFT_TOP,-1,False);
       }
     }
@@ -227,6 +229,8 @@ long WSCvgraphScale::draw(){
   dev->endDraw();
   return WS_NO_ERR;
 }
-
+char* WSCvgraphScale::getDefaultProperty(){
+  return WSNvalue;
+}
 
 
