@@ -1,5 +1,5 @@
 //
-// Copyright (C) 1999-2002 Toshikaz Hirabayashi
+// Copyright (C) 1999-2004 Toshikaz Hirabayashi
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to
@@ -1397,11 +1397,18 @@ fprintf(stderr,"png read error: out of memory..\n");
     fclose(ifile);
     return 0;
 }
+struct jpeg_error_mgr2 {
+  struct jpeg_error_mgr pub;
+  jmp_buf setjmp_buffer;
+};
+
 
 static void ehandler(j_common_ptr jinf,int level){
 }
 
 static void exhandler(j_common_ptr jinf){
+  struct jpeg_error_mgr2* jerr = (struct jpeg_error_mgr2*)jinf->err;
+  longjmp(jerr->setjmp_buffer,1);
 }
 static int chandler(j_decompress_ptr jinf){
 return TRUE;
@@ -1559,12 +1566,19 @@ long JpegReadFileToPixmap(char* filename,long size,GID* mem_gid,GID* mem_gid2,lo
       }
     }
     struct jpeg_decompress_struct    jinf;
-    struct jpeg_error_mgr            jerr;
-
-    jinf.err = jpeg_std_error(&jerr);
+    struct jpeg_error_mgr2            jerr;
+    jinf.err = jpeg_std_error((jpeg_error_mgr*)&jerr);
     jinf.err->emit_message = ehandler;
     jinf.err->error_exit = exhandler;
 
+    if (setjmp(jerr.setjmp_buffer)){
+      jpeg_destroy_decompress(&jinf);
+      if (size == 0){
+        fclose(ifile);
+      }
+      return -1;
+    }
+
     jpeg_create_decompress(&jinf);
     jpeg_set_marker_processor(&jinf,JPEG_COM,chandler);
     if (size == 0){
@@ -1574,6 +1588,7 @@ long JpegReadFileToPixmap(char* filename,long size,GID* mem_gid,GID* mem_gid2,lo
     }
     long reti = jpeg_read_header(&jinf,TRUE);
     if (reti != JPEG_HEADER_OK){
+      jpeg_destroy_decompress(&jinf);
       if (size == 0){
         fclose(ifile);
       }
