@@ -28,6 +28,7 @@
 #include <X11/Xutil.h>
 #include <WScom.h>
 #include <unistd.h>
+#include <setjmp.h>
 
 extern "C" {
 #include <jpeglib.h>
@@ -38,8 +39,14 @@ extern long JpegWriteBufToFp(FILE* fp, char* buf,long width,long height);
 
 static void ehandler(j_common_ptr jinf,int level){
 }
+struct jpeg_error_mgr2 {
+  struct jpeg_error_mgr pub;
+  jmp_buf setjmp_buffer;
+};
 
 static void exhandler(j_common_ptr jinf){
+  struct jpeg_error_mgr2* jerr = (struct jpeg_error_mgr2*)jinf->err;
+  longjmp(jerr->setjmp_buffer,1);
 }
 static int chandler(j_decompress_ptr jinf){
 return TRUE;
@@ -133,15 +140,21 @@ long JpegReadFileToPixmap2(Display* display,Window window,GC gc,char* filename,l
     }
 
     struct jpeg_decompress_struct    jinf;
-    struct jpeg_error_mgr            jerr;
-
-    jinf.err = jpeg_std_error(&jerr);
+    struct jpeg_error_mgr2            jerr;
+    jinf.err = jpeg_std_error((jpeg_error_mgr*)&jerr);
     jinf.err->emit_message = ehandler;
     jinf.err->error_exit = exhandler;
 
+    if (setjmp(jerr.setjmp_buffer)){
+      jpeg_destroy_decompress(&jinf);
+      if (size == 0){
+        fclose(ifile); 
+      }
+      return -1;
+    }
+
     jpeg_create_decompress(&jinf);
     jpeg_set_marker_processor(&jinf,JPEG_COM,chandler);
-
     if (size == 0){
       jpeg_stdio_src(&jinf,ifile);
     }else{
