@@ -1000,8 +1000,10 @@ void WSCdbMysqlRecord::encode(char* buf, char* str)
 		strcpy(str, s.getString(encode));
 	TRACE_U(("encode buf:%s\n", buf));
 	TRACE_U(("encode str:%s\n", str));
-	} else {
+	} else if(buf) {
 		strcpy(str, buf);
+	} else {
+		*str = '\0';
 	}
 }
 char* WSCdbMysqlRecord::decode(char* buf)
