@@ -313,7 +313,7 @@ long WSDnxDraw::beginDraw(WSDdev* dev,long val1,long val2,long val3){
   _clip_x = dx;
   _clip_y = dy;
   _clip_w = dw;
-  _clip_h = dw;
+  _clip_h = dh;
 
   // TODO set visible region to _context
 
