@@ -614,6 +614,10 @@ void WSDnxFormDev::recursiveExposeExecute(short x,short y,WSCushort w,WSCushort
   }
   _setup_pixmap(x,y,w,h,_bg,_bg_pix);
   exposeExecute(x,y,w,h);
+#ifdef F_MEMGID
+  _copy_area(x,y,w,h,x,y,WS_PIXMAP_TO_WINDOW);
+#endif
+
   short px,py;
   getAbstPos(&px,&py);
 
@@ -633,7 +637,9 @@ void WSDnxFormDev::recursiveExposeExecute(short x,short y,WSCushort w,WSCushort
       long dx,dy;
       WSCulong dw,dh;
       WSGFandArea(cx,cy,cw,ch,x+px,y+py,w,h,&dx,&dy,&dw,&dh);
-      child->recursiveExposeExecute(dx -cx, dy -cy, dw, dh);
+      short px2,py2;
+      child->getAbstPos(&px2,&py2);
+      child->recursiveExposeExecute(dx -px2, dy -py2, dw+1, dh+1);
     }
   }
 #endif
