@@ -1694,7 +1694,9 @@ void WSCsheet::setSelectCell(WSCbool val)
 {
 	_selectCell = val;
 	_mouseSelect = False;
-	setFocusCell(-1, -1); 
+	if(val == False) {
+		setFocusCell(-1, -1);
+	}
 }
 long WSCsheet::getFocusCellRect(WSCrect* rect)
 {
