@@ -97,7 +97,7 @@ void WSDwinFontSelect::setWorkWSNfontName(char* data){
   if (_target_name != NULL && _target_name[0] != 0){
     WSDfont* defaultf = WSGIappFontSet()->getFont(8);
     if (defaultf != NULL){
-      char* fname2 = defaultf.getSrc();
+      char* fname2 = defaultf->getSrc();
       sscanf(fname2,"%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%s",
       &e1, &e2, &e3, &e4, &e5, &e6, &e7, &e8, &e9, &e10, &e11,
       &e12, &e13, fname1);
@@ -146,8 +146,8 @@ void WSDwinFontSelect::getWorkWSNfontName(char** fn){
 }
 
 WSMFproperty(WSDwinFontSelect,WSNtype,char*,_target_name,WSGFstrdup(""));
-void WSDwinFontSelect::setWorkWSNtype(char* data){ }
-void WSDwinFontSelect::getWorkWSNtype(char** fn){ }
+void WSDwinFontSelect::setWorkWSNtype(char* data){}
+void WSDwinFontSelect::getWorkWSNtype(char** fn){}
 
 WSMFproperty(WSDwinFontSelect,WSNfont,WSCuchar,_font_no,0);
 void WSDwinFontSelect::setWorkWSNfont(WSCuchar data){
@@ -215,7 +215,7 @@ long WSDwinFontSelect::popup(){
          << _lgfont.lfPitchAndFamily << ","
          << fn.getString(WS_EN_DEFAULT);
     if (_target_name != NULL && _target_name[0] != 0){
-      data << h << " 60c6"
+      data << h << " 60c6";
     }
     delete _font_name;
     _font_name = WSGFstrdup((char*)data);
