@@ -48,6 +48,10 @@ WSDimage* _win_image_create_handler(){
   return image;
 };
 
+struct jpeg_error_mgr2 {
+  struct jpeg_error_mgr pub;
+  jmp_buf setjmp_buffer;
+};
 
 void _win_image_init(){
     WSGIappImageSet()->setCreateHandler(_win_image_create_handler);
@@ -234,6 +238,8 @@ static void ehandler(j_common_ptr jinf,int level){
 }
 
 static void exhandler(j_common_ptr jinf){
+  struct jpeg_error_mgr2* jerr = (struct jpeg_error_mgr2*)jinf->err;
+  longjmp(jerr->setjmp_buffer,1);
 }
 static int chandler(j_decompress_ptr jinf){
 return TRUE;
@@ -330,12 +336,19 @@ HBITMAP JpegReadFileToBitmap(char* filename,long size,WSCulong* w,WSCulong* h){
       }
     }
     struct jpeg_decompress_struct    jinf;
-    struct jpeg_error_mgr            jerr;
-
-    jinf.err = jpeg_std_error(&jerr);
+    struct jpeg_error_mgr2            jerr;
+    jinf.err = jpeg_std_error((jpeg_error_mgr*)&jerr);
     jinf.err->emit_message = ehandler;
     jinf.err->error_exit = exhandler;
 
+    if (setjmp(jerr.setjmp_buffer)){
+      jpeg_destroy_decompress(&jinf);
+      if (size == 0){
+        fclose(ifile);
+      }
+      return -1;
+    }
+
     jpeg_create_decompress(&jinf);
     jpeg_set_marker_processor(&jinf,JPEG_COM,chandler);
     if (size == 0){
@@ -366,6 +379,7 @@ WSMFtrace("2 cinf->global_state=%d\n",jinf.global_state);
     *h = height;
 
     long components = jinf.output_components;
+dbprintf("2 cinf->global_state=%d w,h=%d,%d components=%d\n",jinf.global_state,width,height,components);
 
     unsigned char* buf = new unsigned char[components * height * width*sizeof(JSAMPLE)];
 
