@@ -121,7 +121,7 @@ int WSDwinMessage::extSendMessage(char* dispname, char *message, char *data){
   DWORD dispos;
   LONG ret = RegCreateKeyEx(HKEY_CURRENT_USER,"SoftWare\\WideStudio\\WSTEMP",0,"",REG_OPTION_VOLATILE,
                    KEY_ALL_ACCESS,NULL,&hkey,&dispos);
-printf("WSDwinMessage::extSendMessage hkey=0x%x\n",hkey);
+//printf("WSDwinMessage::extSendMessage hkey=0x%x\n",hkey);
 
   if (ret != ERROR_SUCCESS){
     return WS_ERR;
@@ -148,7 +148,7 @@ printf("WSDwinMessage::extSendMessage hkey=0x%x\n",hkey);
                                 SMTO_NORMAL,1000,&result);
   if(ret == False){
     GlobalDeleteAtom(atom);
-printf("send error.. delete atom..\n");
+//printf("send error.. delete atom..\n");
   }
   return 0;
 }
