@@ -1038,8 +1038,23 @@ long WSDwindraw::drawStretchedImage(short x,short y,WSCushort w,WSCushort h,WSDi
     SetStretchBltMode(_hdc,STRETCH_DELETESCANS);
 
     if (pix2 == 0){
-      int ret = StretchBlt(_hdc,x,y,w,h,mdc,0,0,iw,ih,SRCCOPY);
+      if (_printer_hdc != 0){
+        HDC mdc2 = CreateCompatibleDC(mdc);
+        HPALETTE plbk2 = SelectPalette(mdc2,pl,FALSE);
+        RealizePalette(mdc2);
+        HBITMAP pix2 = CreateCompatibleBitmap(mdc,w,h);
+        HBITMAP pxbk2 = (HBITMAP)SelectObject(mdc2,(void*)pix2);
+        SetMapMode(mdc2,GetMapMode(mdc));
+        StretchBlt(mdc2,0,0,w,h,mdc,0,0,iw,ih,SRCCOPY);
+        int ret = StretchBlt(_hdc,x,y,w,h,mdc2,0,0,w,h,SRCCOPY);
+dbprintf("WSDwindraw::drawStretchedImage _hdc=0x%x mdc=0x%x pr ret=%d %d,%d,%d,%d<-%d,%d \n",_hdc,mdc,ret,x,y,w,h,iw,ih);
+        SelectObject(mdc2,pxbk2);
+        DeleteObject(pix2);
+        DeleteDC(mdc2);
+      }else{
+        int ret = StretchBlt(_hdc,x,y,w,h,mdc,0,0,iw,ih,SRCCOPY);
 dbprintf("WSDwindraw::drawStretchedImage _hdc=0x%x mdc=0x%x ret=%d %d,%d,%d,%d<-%d,%d \n",_hdc,mdc,ret,x,y,w,h,iw,ih);
+      }
     }else{
       _draw_stretch_image_with_mask(_hdc,mdc,mdc2,pix,pix2,pl,x,y,w,h,
                                                             0,0,iw,ih);
@@ -1171,8 +1186,20 @@ dbprintf("WSDwindraw::drawImage _pr_scale_x=%f _pr_scale_y=%f\n",_pr_scale_x,_pr
       WSCulong iw = image->getImageWidth();
       WSCulong ih = image->getImageHeight();
       if (pix2 == 0){
-        int ret = StretchBlt(_hdc,dx2,dy2,dw,dh,mdc,dx -x -xoff,dy-y-yoff,iw2,ih2,SRCCOPY);
-dbprintf("WSDwindraw::drawImage _hdc=0x%x mdc=0x%x ret=%d %d,%d,%d,%d->%d,%d \n",_hdc,mdc,ret,dx,dy,dw,dh,dx -x -xoff,dy-y-yoff);
+        HDC mdc2 = CreateCompatibleDC(mdc);
+        HPALETTE plbk2 = SelectPalette(mdc2,pl,FALSE);
+        RealizePalette(mdc2);
+        HBITMAP pix2 = CreateCompatibleBitmap(mdc,dw,dh);
+        HBITMAP pxbk2 = (HBITMAP)SelectObject(mdc2,(void*)pix2);
+        SetMapMode(mdc2,GetMapMode(mdc));
+        int ret = StretchBlt(mdc2,0,0,dw,dh,mdc,dx -x -xoff,dy -y -yoff,iw2,ih2,SRCCOPY);
+dbprintf("WSDwindraw::drawImage _hdc=0x%x mdc=0x%x ret=%d %d,%d,%d,%d->%d,%d err=0x%x err=%d\n",_hdc,mdc,ret,dx2,dy2,dw,dh,dx -x -xoff,dy-y-yoff,GetLastError(),GetLastError());
+        ret = BitBlt(_hdc,dx2,dy2,dw,dh,mdc2,0,0,SRCCOPY);
+//        int ret = StretchBlt(_hdc,dx2,dy2,dw,dh,mdc,dx -x -xoff,dy-y-yoff,iw2,ih2,SRCCOPY);
+dbprintf("WSDwindraw::drawImage _hdc=0x%x mdc=0x%x st ret=%d %d,%d,%d,%d->%d,%d err=0x%x err=%d\n",_hdc,mdc,ret,dx2,dy2,dw,dh,dx -x -xoff,dy-y-yoff,GetLastError(),GetLastError());
+        SelectObject(mdc2,pxbk2);
+        DeleteObject(pix2);
+        DeleteDC(mdc2);
       }else{
 //        StretchBlt(_hdc,dx,dy,dw,dh,mdc2,dx -x -xoff,dy-y-yoff,iw2,ih2,SRCAND);
 //        BitBlt(mdc2,0,0,iw,ih,mdc2,0,0,DSTINVERT);
@@ -1337,7 +1364,18 @@ long WSDwindraw::drawImage(short x,short y,short sx,short sy,WSCushort w,WSCusho
     WSCulong iw = image->getImageWidth();
     WSCulong ih = image->getImageHeight();
     if (pix2 == 0){
-      StretchBlt(_hdc,dx2,dy2,dw,dh,mdc,dx -x +sx,dy -y +sy,iw2,ih2,SRCCOPY);
+      HDC mdc2 = CreateCompatibleDC(mdc);
+      HPALETTE plbk2 = SelectPalette(mdc2,pl,FALSE);
+      RealizePalette(mdc2);
+      HBITMAP pix2 = CreateCompatibleBitmap(mdc,dw,dh);
+      HBITMAP pxbk2 = (HBITMAP)SelectObject(mdc2,(void*)pix2);
+      SetMapMode(mdc2,GetMapMode(mdc));
+      StretchBlt(mdc2,0,0,dw,dh,mdc,dx -x +sx,dy -y +sy,iw2,ih2,SRCCOPY);
+      BitBlt(_hdc,dx2,dy2,dw,dh,mdc2,0,0,SRCCOPY);
+//      StretchBlt(_hdc,dx2,dy2,dw,dh,mdc,dx -x +sx,dy -y +sy,iw2,ih2,SRCCOPY);
+      SelectObject(mdc2,pxbk2);
+      DeleteObject(pix2);
+      DeleteDC(mdc2);
     }else{
 //      StretchBlt(_hdc,dx,dy,dw,dh,mdc2,dx -x +sx,dy -y +sy,iw2,ih2,SRCAND);
 //      BitBlt(mdc2,0,0,iw,ih,mdc2,0,0,DSTINVERT);
