@@ -197,6 +197,12 @@ extern int XUGetLocale();
        &e1, &e2, &e3, &e4, &e5, &e6, &e7, &e8, &e9, &e10, &e11,
        &e12, &e13, fname1);
 
+  char dust[1024];
+  if (_virtual_flag != False){
+    char* fname2 = getFontName();
+    sscanf(fname2,"%d %s",&e1,dust);
+  }
+
 WSMFtrace("font=#%s#\n",fname1);
 
   _lgfont.lfHeight = e1;
