@@ -95,8 +95,10 @@ long WSDwinsocket::connect(){
   struct hostent  *hp;
   if (!strcmp(_dest_naddr,"")){
     hp = gethostbyname("localhost");
+dbprintf("WSDwinsocket::connect() dest addr is local host\n");
   }else{
     hp = gethostbyname((char*)_dest_naddr);
+dbprintf("WSDwinsocket::connect() dest addr is %s\n",(char*)_dest_naddr);
   }
   server.sin_family = AF_INET;
   if (hp == NULL){
@@ -108,8 +110,10 @@ long WSDwinsocket::connect(){
     server.sin_addr.s_addr = *(unsigned long *)hp->h_addr;
   }
   server.sin_port = htons( _dest_port );
+dbprintf("WSDwinsocket::connect() dest port is %d\n",_dest_port);
 
   if( ::connect(_socket, (struct sockaddr *)&server,sizeof server) < 0 ){
+dbprintf("WSDwinsocket::connect() connect err.\n");
     seterr();
     return WS_ERR;
   }
@@ -131,30 +135,38 @@ long WSDwinsocket::listen(){
   server.sin_family = AF_INET;
   if (!strcmp((char*)_naddr,"")){
     server.sin_addr.s_addr = INADDR_ANY;
+dbprintf("WSDwinsocket::listen() bind addr is INADDR_ANY\n");
   }else{
     server.sin_addr.s_addr = 
         (unsigned long)inet_addr((char*)_naddr);
+dbprintf("WSDwinsocket::listen() bind addr is %s\n",(char*)_naddr);
   }
   server.sin_port = htons( _port );
+dbprintf("WSDwinsocket::listen() bind port is %d\n",_port);
   int val;
   val = 1;
   setsockopt(_socket, SOL_SOCKET, SO_REUSEADDR, (char *)&val, sizeof val);
 
   if( bind(_socket, (struct sockaddr *)&server, sizeof server) < 0){
     seterr();
+dbprintf("WSDwinsocket::listen() bind error\n");
     return WS_ERR;
   }
+#if 0 //not need..
   OSVERSIONINFO osvi;
   osvi.dwOSVersionInfoSize = sizeof(OSVERSIONINFO);
   GetVersionEx(&osvi);
   if (osvi.dwPlatformId == VER_PLATFORM_WIN32_NT){
     int len;
     if(getsockname(_socket, (struct sockaddr *)&server, &len) < 0){
+dbprintf("WSDwinsocket::listen() getsockname error\n");
       seterr();
       return WS_ERR;
     }
   }
+#endif
   if ( ::listen(_socket, 5) != 0){
+dbprintf("WSDwinsocket::listen() listen error\n");
     seterr();
     return WS_ERR;
   }
@@ -189,6 +201,7 @@ void* WSDwinsocket::accept(){
 //    *from_addr = sock_addr.sin_addr.s_addr;
 //  }
   _set_dest_addr_(htonl( sock_addr.sin_addr.s_addr));
+dbprintf("WSDwinsocket::accept() sock=0x%x from_addr=0x%x\n",sock,htonl(sock_addr.sin_addr.s_addr));
   return (void*)sock;
 }
 
@@ -206,16 +219,18 @@ void* WSDwinsocket::_accept_thread_(void* ptr){
   while(1){
     struct sockaddr_in sock_addr;
     int hlen = sizeof(sock_addr);
-//printf("accept start...\n");
+dbprintf("WSDwinsocket::_asccept_thread_() accept start...\n");
     int sock = ::accept(_this->_socket,(sockaddr*)&sock_addr,&hlen);
     _this->seterr();
-//printf("accept done...\n");
+dbprintf("WSDwinsocket::_asccept_thread_() accept done... sock=0x%x from_addr=0x%x\n",sock,htonl(sock_addr.sin_addr.s_addr));
     if (sock < 0){
 //printf("return2\n");
+dbprintf("WSDwinsocket::_asccept_thread_() accept return1\n");
       return 0;
     }
     if (_this->_stop_accept != False){
 //printf("return3\n");
+dbprintf("WSDwinsocket::_asccept_thread_() accept return2\n");
       _this->_stop_accept = False;
       return 0;
     }
