@@ -44,10 +44,10 @@ class _init_app_class_{
 static _init_app_class_ _execute_app_class_;
 
 //--- OBJECT execute auto initialize ---//
-extern WSDLEX void _create_win_newwin000();
+extern WSDLEX WSCbase* _create_win_newwin000();
 class _initialize_window_0{
  public: _initialize_window_0(){
-  WSGIappDev()->setInitHandler(_create_win_newwin000);
+  WSGIappDev()->setInitHandler((void(*)())_create_win_newwin000);
  };
 };
 static _initialize_window_0 _execute_initialize_0;
