@@ -615,17 +615,11 @@ static Atom prop6 = 0;
 //printf("SelectionReg target=0x%x prop=0x%x prop2=0x%x prop3=0x%x prop4=0x%x prop5=0x%x\n", e.xselectionrequest.target,prop,prop2,prop3,prop4,prop5);
     if (e.xselectionrequest.selection == XA_PRIMARY &&
         e.xselectionrequest.target == prop4 ){
-       Atom ar[4];
-//TEST
-       ar[0] = prop5;
-       ar[1] = prop2;
-       ar[2] = prop;
-       ar[3] = prop3;
-#if 0
-       ar[0] = prop4;
-       ar[1] = prop2;
-       ar[2] = prop3;
-#endif
+      Atom ar[8];
+      ar[0] = prop5;
+      ar[1] = prop2;
+      ar[2] = prop;
+      ar[3] = prop3;
       XChangeProperty(_disp,se.requestor,se.property,se.target,
                       32,PropModeReplace,(unsigned char*)ar,4);
 //TEST 4 -> 3
@@ -635,76 +629,90 @@ static Atom prop6 = 0;
       char* str = WSGIappKeyboard()->WSDkeyboard::getSelectedString(
          WSGIappLocaleSet()->getSystemLocaleEncoding());
       XChangeProperty(_disp,se.requestor,se.property,se.target,
-                      8,PropModeReplace,(unsigned char*)str,strlen(str)+1);
-//printf("xappdev:: send data..#%s# %d %d %d\n",str,XA_PRIMARY,XA_STRING,se.property);
+                      8,PropModeReplace,(unsigned char*)str,strlen(str));
+//printf("xappdev:: send data.. prop.. #%s# %d %d %d\n",str,XA_PRIMARY,XA_STRING,se.property);
     }else if (e.xselectionrequest.selection == XA_PRIMARY &&
               e.xselectionrequest.target == XA_STRING ){
-//printf("send.. string target=0x%x XA_STRING\n",e.xselectionrequest.target);
+//printf("xappdev:: send data.. string target=0x%x XA_STRING\n",e.xselectionrequest.target);
       char* str = WSGIappKeyboard()->WSDkeyboard::getSelectedString(
                                WSGIappLocaleSet()->getSystemLocaleEncoding());
-      WSCushort* ustr = WSGFgetUCS2(str,
-                               WSGIappLocaleSet()->getSystemLocaleEncoding());
-      int i;
-      long ulen = WSGFstrlenUCS2(ustr);
+      char* str2 = NULL;
       WSCbool need_convert = False;
-      char* str2 = new char[ulen*8+1];
-      int cnt = 0;
-      for(i=0; i<ulen; i++){
-        if (ustr[i] & 0xff00){
-          need_convert = True;
-          str2[cnt++] = '\\';
-          str2[cnt++] = 'x';
-          str2[cnt++] = '{';
-          WSCuchar val = ((ustr[i] >> 12) & 0xf);
-          if (val >= 10){
-            val += ('A' -10);
+      WSCushort* ustr = NULL;
+      if ( WSGIappLocaleSet()->getSystemLocaleEncoding() == WS_EN_EUCJP){
+        char b1[5];
+        b1[0] = 0x1b;
+        b1[1] = 0x24;
+        b1[2] = 0x29;
+        b1[3] = 0x42;
+        b1[4] = 0;
+        str2 = new char[strlen(str)+8];
+        strcpy(str2,b1);
+        strcpy(&(str2[4]),str);
+        need_convert = True;
+      }else{
+        ustr = WSGFgetUCS2(str,WSGIappLocaleSet()->getSystemLocaleEncoding());
+        int i;
+        long ulen = WSGFstrlenUCS2(ustr);
+        str2 = new char[ulen*8+1];
+        int cnt = 0;
+        for(i=0; i<ulen; i++){
+          if (ustr[i] & 0xff00){
+            need_convert = True;
+            str2[cnt++] = '\\';
+            str2[cnt++] = 'x';
+            str2[cnt++] = '{';
+            WSCuchar val = ((ustr[i] >> 12) & 0xf);
+            if (val >= 10){
+              val += ('A' -10);
+            }else{
+              val += '0';
+            }
+            str2[cnt++] = val;
+            val = ((ustr[i] >> 8) & 0xf);
+            if (val >= 10){
+              val += ('A' -10);
+            }else{
+              val += '0';
+            }
+            str2[cnt++] = val;
+            val = ((ustr[i] >> 4) & 0xf);
+            if (val >= 10){
+              val += ('A' -10);
+            }else{
+              val += '0';
+            }
+            str2[cnt++] = val;
+            val = (ustr[i] & 0xf);
+            if (val >= 10){
+              val += ('A' -10);
+            }else{
+              val += '0';
+            }
+            str2[cnt++] = val;
+            str2[cnt++] = '}';
           }else{
-            val += '0';
+            str2[cnt] = ustr[i];
+            cnt++;
           }
-          str2[cnt++] = val;
-          val = ((ustr[i] >> 8) & 0xf);
-          if (val >= 10){
-            val += ('A' -10);
-          }else{
-            val += '0';
-          }
-          str2[cnt++] = val;
-		  val = ((ustr[i] >> 4) & 0xf);
-		  if (val >= 10){
-            val += ('A' -10);
-          }else{
-            val += '0';
-          }
-          str2[cnt++] = val;
-          val = (ustr[i] & 0xf);
-          if (val >= 10){
-            val += ('A' -10);
-          }else{
-            val += '0';
-          }
-          str2[cnt++] = val;
-          str2[cnt++] = '}';
-        }else{
-          str2[cnt] = ustr[i];
-          cnt++;
+          str2[cnt] = 0;
         }
-        str2[cnt] = 0;
       }
       if (need_convert == False){
         XChangeProperty(_disp,se.requestor,se.property,se.target,
-                      8,PropModeReplace,(unsigned char*)str,strlen(str)+1);
+                      8,PropModeReplace,(unsigned char*)str,strlen(str));
       }else{
         XChangeProperty(_disp,se.requestor,se.property,se.target,
-                      8,PropModeReplace,(unsigned char*)str2,strlen(str2)+1);
+                      8,PropModeReplace,(unsigned char*)str2,strlen(str2));
       }
       delete str2;
       delete ustr;
     }else if (e.xselectionrequest.selection == XA_PRIMARY &&
          e.xselectionrequest.target == prop5 ){
-//printf("send.. string target=0x%x UTF8_STRING\n",e.xselectionrequest.target);
+//printf("xappdev:: send data.. string target=0x%x UTF8_STRING\n",e.xselectionrequest.target);
       char* str = WSGIappKeyboard()->WSDkeyboard::getSelectedString(WS_EN_UTF8);
       XChangeProperty(_disp,se.requestor,se.property,se.target,
-                      8,PropModeReplace,(unsigned char*)str,strlen(str)+1);
+                      8,PropModeReplace,(unsigned char*)str,strlen(str));
 //printf("xappdev:: send data2..#%s# %d %d %d\n",str,XA_PRIMARY,XA_STRING,se.property);
 #if 0
     }else if (e.xselectionrequest.selection == XA_PRIMARY &&
@@ -761,7 +769,7 @@ dbprintf("WSDxappDev::_dispatchEvent %s:%d done5\n",__FILE__,__LINE__);
         for(i=0;i<nitems;i++){
 //printf("ar[%d]=0x%x %s =0x%x\n",i,ar[i],XGetAtomName(_disp,ar[i]),prop6);
           if (ar[i] == prop6){
-//printf("ar[%d]=0x%x %s hit!\n",i,ar[i],XGetAtomName(_disp,ar[i]));
+//printf("hit prop6 ar[%d]=0x%x %s hit! request by prop6\n",i,ar[i],XGetAtomName(_disp,ar[i]));
             fl = True;
             XConvertSelection(_disp,XA_PRIMARY,prop6,prop6,e.xselection.requestor,e.xselection.time);
             break;
@@ -771,6 +779,19 @@ dbprintf("WSDxappDev::_dispatchEvent %s:%d done5\n",__FILE__,__LINE__);
           for(i=0;i<nitems;i++){
 //printf("ar[%d]=0x%x %s =0x%x\n",i,ar[i],XGetAtomName(_disp,ar[i]),prop5);
             if (ar[i] == prop5){
+//printf("hit prop5 ar[%d]=0x%x %s hit! request by prop5\n",i,ar[i],XGetAtomName(_disp,ar[i]));
+//printf("ar[%d]=0x%x %s hit\n",i,ar[i],XGetAtomName(_disp,ar[i]));
+              fl = True;
+              XConvertSelection(_disp,XA_PRIMARY,prop5,prop5,e.xselection.requestor,e.xselection.time);
+              break;
+            }
+          }
+        }
+        if (fl == False){
+          for(i=0;i<nitems;i++){
+//printf("ar[%d]=0x%x %s =0x%x\n",i,ar[i],XGetAtomName(_disp,ar[i]),prop2);
+            if (ar[i] == prop2){
+//printf("hit prop2 ar[%d]=0x%x %s hit! request by prop2\n",i,ar[i],XGetAtomName(_disp,ar[i]));
 //printf("ar[%d]=0x%x %s hit\n",i,ar[i],XGetAtomName(_disp,ar[i]));
               fl = True;
               XConvertSelection(_disp,XA_PRIMARY,prop2,prop2,e.xselection.requestor,e.xselection.time);
@@ -782,6 +803,7 @@ dbprintf("WSDxappDev::_dispatchEvent %s:%d done5\n",__FILE__,__LINE__);
           for(i=0;i<nitems;i++){
 //printf("ar[%d]=0x%x %s =0x%x\n",i,ar[i],XGetAtomName(_disp,ar[i]),prop2);
             if (ar[i] == prop){
+//printf("hit prop ar[%d]=0x%x %s hit! request by prop\n",i,ar[i],XGetAtomName(_disp,ar[i]));
 //printf("ar[%d]=0x%x %s hit\n",i,ar[i],XGetAtomName(_disp,ar[i]));
               fl = True;
               XConvertSelection(_disp,XA_PRIMARY,prop,prop,e.xselection.requestor,e.xselection.time);
@@ -789,6 +811,22 @@ dbprintf("WSDxappDev::_dispatchEvent %s:%d done5\n",__FILE__,__LINE__);
             }
           }
         }
+
+        if (fl == False){
+          for(i=0;i<nitems;i++){
+//printf("ar[%d]=0x%x %s =0x%x\n",i,ar[i],XGetAtomName(_disp,ar[i]),prop2);
+            if (ar[i] == prop3){
+//printf("hit prop3 ar[%d]=0x%x %s hit! request by prop3\n",i,ar[i],XGetAtomName(_disp,ar[i]));
+//printf("ar[%d]=0x%x %s hit\n",i,ar[i],XGetAtomName(_disp,ar[i]));
+              fl = True;
+              XConvertSelection(_disp,XA_PRIMARY,prop3,prop3,e.xselection.requestor,e.xselection.time);
+              break;
+            }
+          }
+        }
+
+
+
       }
     }else
 
@@ -836,7 +874,7 @@ dbprintf("WSDxappDev::_dispatchEvent %s:%d done5\n",__FILE__,__LINE__);
         e.xselection.target == prop &&
         e.xselection.property == prop ){
 
-//printf("XA_TEXT\n");
+//printf("XA_TEXT receive..\n");
       if (XGetWindowProperty(_disp,XtWindow(appWidget()),prop,
                               0,8192,False,AnyPropertyType,&type,&fmt,&nitems,
                               &left,(WSCuchar**)&buf) == Success &&
@@ -924,6 +962,7 @@ dbprintf("WSDxappDev::_dispatchEvent %s:%d done5\n",__FILE__,__LINE__);
     if (e.xselection.selection == XA_PRIMARY &&
         e.xselection.target == prop2 &&
         e.xselection.property == prop2 ){
+//printf("COMPOUND_TEXT receive..\n");
       if (XGetWindowProperty(_disp,XtWindow(appWidget()),prop2,
                               0,8192,True,AnyPropertyType,&type,&fmt,&nitems,
                               &left,(WSCuchar**)&buf) == Success &&
@@ -950,6 +989,7 @@ dbprintf("WSDxappDev::_dispatchEvent %s:%d done5\n",__FILE__,__LINE__);
         b1[2] = 0x28; 
         b1[3] = 0x42; 
         b1[4] = 0; 
+
         if (tmp.isExist(b1) != -1){
           char* str = WSGFcreateEucStringFromJisStr(buffer);
           tmp.setString(str,WS_EN_EUCJP);
@@ -967,6 +1007,7 @@ dbprintf("WSDxappDev::_dispatchEvent %s:%d done5\n",__FILE__,__LINE__);
         b1[3] = 0; 
         tmp.replaceString(b1,"",0);
 //printf("0x%x 0x%x 0x%x 0x%x nitems=%d\n",buffer[0],buffer[1],buffer[2],buffer[3],nitems);
+
         WSGIxkeyboard()->WSDkeyboard::setSelectedString(
                                     tmp.getString(encoding),encoding);
       }
