@@ -173,6 +173,14 @@ long WSDxfont::initialize(){
     _fmly.setString(fmly);
     _wght.setString(wght);
     _slant.setString(slant);
+
+    char dust[1024];
+    if (_virtual_flag != False){
+      char* fname2 = getFontName();
+      sscanf(fname2,"%d %s",&_font_height,dust);
+    }
+
+
 //  }else{
 //    //Japanese
 //    japanese = True;
