@@ -83,12 +83,14 @@ WSCbaseDialog(base,objName){
   opt005 = NULL;
   opt006 = NULL;
   _font_name = WSGFstrdup("14 jisx0201.1976 jisx0208.1983 * misc misc misc");
+  _target_name = WSGFstrdup("");
   _rep = NULL;
   _font_no = 0;
   _title_bar = WS_ONLY_TITLE;
 
   WSMFpropertyCreateStart
     WSMFpropertyCreate(WSNfontName,char*,_font_name,WSSfontName);
+    WSMFpropertyCreate(WSNtype,char*,_target_name,WSStype);
 //    WSMFpropertyCreate(WSNreplyHandler,void*,_rep,WSSreplyHandler);
     WSMFpropertyCreate(WSNfont,WSCuchar,_font_no,WSSfont);
 
@@ -103,7 +105,19 @@ WSMFproperty(WSDxfontSelect,WSNfontName,char*,_font_name,WSGFstrdup("14 jisx0201
 void WSDxfontSelect::setWorkWSNfontName(char* data){
   WSCstring str(data);
   _size = atoi((char*)str.getWord(0));
-
+  if (_target_name != NULL && _target_name[0] != 0){
+    _ec = "iso8859";
+    _kc = "*";
+    _gc = "*";
+    _ev = "*";
+    _kv = "*";
+    _gv = "*";
+    _fmly = "*";
+    _wght = "*";
+    _slant = "*";
+    updateList();
+    return;
+  }
 //  if (strcmp(WSGIappLocaleSet()->getDefaultLocaleName(),WS_LOCALE_JAPANESE)){
     //C
     _ec = str.getWord(1);
@@ -129,6 +143,14 @@ void WSDxfontSelect::setWorkWSNfontName(char* data){
 }
 
 void WSDxfontSelect::getWorkWSNfontName(char** fn){
+  if (_target_name != NULL && _target_name[0] != 0){
+    WSCstring str( WSGFltoa(_size) );
+    str << " 60c6";
+    delete _font_name;
+    _font_name = WSGFstrdup((char*)str);
+    *fn = _font_name;
+    return;
+  }
   WSCstring str( WSGFltoa(_size));
 //  if (strcmp(WSGIappLocaleSet()->getDefaultLocaleName(),WS_LOCALE_JAPANESE)){
     //C
@@ -143,6 +165,9 @@ void WSDxfontSelect::getWorkWSNfontName(char** fn){
   _font_name = WSGFstrdup((char*)str);
   *fn = _font_name;
 }
+WSMFproperty(WSDxfontSelect,WSNtype,char*,_target_name,WSGFstrdup(""));
+void WSDxfontSelect::setWorkWSNtype(char* data){}
+void WSDxfontSelect::getWorkWSNtype(char** fn){}
 
 //WSMFproperty(WSDxfontSelect,WSNreplyHandler,void*,_rep,NULL);
 //void WSDxfontSelect::setWorkWSNreplyHandler(void*){ }
@@ -165,6 +190,7 @@ void WSDxfontSelect::getWorkWSNfont(WSCuchar* data){}
 WSDxfontSelect::~WSDxfontSelect(){
   delAllProcedure();
   delete _font_name;
+  delete _target_name;
 }
 
 long WSDxfontSelect::initialize(){
@@ -568,7 +594,12 @@ void WSDxfontSelect::xfdVch(WSCbase* object){
 //printf("WSDxfontSelect::xfdVch fno=%d %s\n",fontn,(char*)buf);
   WSDfont* font = WSGIappFontSet()->getFont((short)fontn);
   if (font != NULL){
-    font->setFontName((char*)buf);
+    font->setSrc((char*)buf);
+    if (base->_target_name != NULL && base->_target_name[0] != 0){
+      WSCstring str( WSGFltoa(base->_size) );
+      str << " 60c6";
+      font->setFontName((char*)str);
+    }
   }
   if (base->lb004 != NULL){
     base->lb004->setPropertyV(WSNfont,(WSCuchar)fontn);
