@@ -176,7 +176,7 @@ WSMFtrace("ERROR. in WSDximage::initialize(). Library libXpm.so is invalid. \nso
      GC gc = WSGIxwinAppDev()->appGC2();
      static void* dl = NULL;
      static long dl_init = 0;
-     static long (*fn)(Display*,Window,GC,char*,Pixmap*,long*,long*) = NULL;
+     static long (*fn)(Display*,Window,GC,char*,long,Pixmap*,long*,long*) = NULL;
 
      if (dl_init == 0){
 #ifndef MacOS
@@ -198,7 +198,7 @@ WSMFtrace("ERROR. in WSDximage::initialize(). Library jpg.so open error. \nso, j
 WSMFtrace("ERROR. in WSDximage::initialize(). Library jpg.bundle open error. \nso, jpeg image can not support...\n");
 #endif //MacOS
        }else{
-         fn = (long (*)(Display*,Window,GC,char*,Pixmap*,long*,long*))
+         fn = (long (*)(Display*,Window,GC,char*,long,Pixmap*,long*,long*))
                 dlsym(dl,"JpegReadFileToPixmap");
          if (fn == NULL){
 WSMFtrace("ERROR. in WSDximage::initialize(). Library jpg.so is invalid. \nso, jpeg image can not support...\n");
@@ -206,9 +206,25 @@ WSMFtrace("ERROR. in WSDximage::initialize(). Library jpg.so is invalid. \nso, j
        }
      }
      if (fn != NULL){
-       long reti = fn( app->display(), XtWindow(app->appWidget()),gc,
-                       load_file_name, &pixmap_file, &width,&height);
-
+       long reti = 0;
+       if (strncmp("http://",in.getString(),7)){
+         reti = fn( app->display(), XtWindow(app->appWidget()),gc,
+                       load_file_name,0,&pixmap_file, &width,&height);
+       }else{
+         char*  pbuf = NULL;
+         long size = 0;
+         long reti;
+         char*  ctype = NULL;
+         long  ishtml = 0;
+         WSGFloadRemoteFile(in.getString(),&pbuf,&ctype,&size,&ishtml,1);
+         if (pbuf != NULL){
+           reti = fn( app->display(), XtWindow(app->appWidget()),gc,
+                       pbuf,size,&pixmap_file, &width,&height);
+           free(pbuf);
+         }else{
+           reti = 1;
+         }
+       }
        if (reti == 0){
          setImageWidth(width);
          setImageHeight(height);
